@@ -11,7 +11,7 @@ class HistoryCommand(Command):
 '''
 
     options = [
-        _option('job-dir'),
+        _option('job-dir', 'j', 'target directory'),
     ]
 
     def handle(self):
