@@ -15,7 +15,7 @@ class PeakCommand(Command):
 '''
 
     options = [
-        _option('job-dir'),
+        _option('job-dir', 'j', 'target directory'),
         option('force', 'f'),
     ]
 
